OC.L10N.register(
    "files",
    {
    "File could not be found" : "Ezin izan da fitxategia aurkitu",
    "Move or copy" : "Mugitu edo kopiatu",
    "Download" : "Deskargatu",
    "Delete" : "Ezabatu",
    "Tags" : "Etiketak",
    "Show list view" : "Erakutsi zerrenda ikuspegia",
    "Show grid view" : "Erakutsi sareta ikuspegia",
    "Home" : "Etxea",
    "Close" : "Itxi",
    "Favorites" : "Gogokoak",
    "Could not create folder \"{dir}\"" : "Ezin izan da \"{dir}\" karpeta sortu",
    "This will stop your current uploads." : "Honek martxan dauzkazun igoerak geldituko ditu.",
    "Upload cancelled." : "Karga bertan behera utzi da.",
    "Processing files …" : "Fitxategiak prozesatzen...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} kargatu karpeta bat delako edo 0 byte dituelako",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, {size1} kargatzen ari zara baina {size2} daude libre soilik",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" helburuko karpeta ez da existitzen jadanik",
    "Not enough free space" : "Ez dago leku libre nahikorik",
    "An unknown error has occurred" : "Errore ezezagun bat gertatu da",
    "File could not be uploaded" : "Fitxategia ezin izan da kargatu",
    "Uploading …" : "Kargatzen...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Ez da onartzen elementu hori kargatzea",
    "Target folder does not exist any more" : "Helburuko karpeta ez da existitzen jadanik",
    "Operation is blocked by access control" : "Sarbide kontrolak eragiketa blokeatu du",
    "Error when assembling chunks, status code {status}" : "Errorea zatiak elkartzean, egoera kodea {status}",
    "Actions" : "Ekintzak",
    "Rename" : "Berrizendatu",
    "Move" : "Mugitu",
    "Copy" : "Kopiatu",
    "Choose target folder" : "Aukeratu helburuko karpeta",
    "Edit locally" : "Editatu lokalean",
    "Open" : "Ireki",
    "Delete file" : "Ezabatu fitxategia",
    "Delete folder" : "Ezabatu karpeta",
    "Disconnect storage" : "Deskonektatu biltegia",
    "Leave this share" : "Utzi partekatze hau",
    "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
    "Files" : "Fitxategiak",
    "Details" : "Xehetasunak",
    "Please select tag(s) to add to the selection" : "Hautatu etiketa(k) hautapenera gehitzeko",
    "Apply tag(s) to selection" : "Aplikatu etiketa(k) hautapenari",
    "Select directory \"{dirName}\"" : "Hautatu \"{dirName}\" direktorioa",
    "Select file \"{fileName}\"" : "Hautatu \"{fileName}\" fitxategia",
    "Pending" : "Zain",
    "Unable to determine date" : "Ezin izan da data zehaztu",
    "This operation is forbidden" : "Eragiketa hau debekatuta dago",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
    "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
    "Could not move \"{file}\", target exists" : "Ezin izan da \"{file}\" lekuz aldatu, helburua existitzen da jadanik",
    "Could not move \"{file}\"" : "Ezin izan da \"{file}\" lekuz aldatu",
    "copy" : "kopiatu",
    "Could not copy \"{file}\", target exists" : "Ezin izan da \"{file}\" kopiatu; helburua existitzen da",
    "Could not copy \"{file}\"" : "Ezin izan da \"{file}\" kopiatu",
    "Copied {origin} inside {destination}" : "{origin} kopiatu da {destination} barruan",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} eta beste {nbfiles} fitxategi {destination} barruan kopiatu dira",
    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
    "{newName} already exists" : "{newName} existitzen da dagoeneko",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ezin izan da \"{fileName}\" berrizendatu, ez da existitzen jada",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" izena dagoeneko erabiltzen da \"{dir}\" karpetan. Aukeratu beste izen bat.",
    "Could not rename \"{fileName}\"" : "Ezin izan da \"{fileName}\" berrizendatu ",
    "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
    "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
    "Could not create folder \"{dir}\" because it already exists" : "Ezin izan da \"{dir}\" karpeta sortu, dagoeneko existitzen delako",
    "Could not fetch file details \"{file}\"" : "Ezin izan dira \"{file}\" fitxategiaren xehetasunak eskuratu",
    "Error deleting file \"{fileName}\"." : "Errorea \"{fileName}\" fitxategia ezabatzerakoan.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzarik aurkitu beste karpetetan",
    "Enter more than two characters to search in other folders" : "Sartu bi karaktere baino gehiago beste karpetetan bilatu ahal izateko",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
    "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
    "{dirs} and {files}" : "{dirs} eta {files}",
    "_including %n hidden_::_including %n hidden_" : ["ezkutuko %n barne","ezkutuko %n barne"],
    "You do not have permission to upload or create files here" : "Ez duzu hemen fitxategiak kargatzeko edo sortzeko baimenik",
    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n kargatzen","%n fitxategi kargatzen"],
    "New file/folder menu" : "Fitxategi/karpeta berri menua",
    "Select file range" : "Hautatu fitxategi-barrutia",
    "{used}%" : "%{used}",
    "{used} of {quota} used" : "{used} / {quota} erabilita",
    "{used} used" : "{used} erabilita",
    "\"{name}\" is an invalid file name." : "\"{name}\" fitxategi-izen baliogabea da.",
    "File name cannot be empty." : "Fitxategi-izena ezin da hutsa izan.",
    "\"/\" is not allowed inside a file name." : "\"/\" ez da onartzen fitxategi-izenen barnean.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi-mota ez da onartzen",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} erabiltzailearen biltegia beteta dago, fitxategiak ezin dira jada eguneratu edo sinkronizatu!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{MountPoint}\" taldeko karpeta beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{MountPoint}\" kanpoko biltegia beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Zure biltegiratzea beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner}-(r)en biltegia betetzear dago ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" talde karpeta betetzear dago ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" kanpoko biltegia betetzear dago ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Zure biltegia betetzear dago ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" emaitza","\"{filter}\" emaitza"],
    "View in folder" : "Ikusi karpetan",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
    "Path" : "Bidea",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Gogoko gisa markatua",
    "Favorite" : "Gogokoa",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
    "You can only favorite a single file or folder at a time" : "Fitxategi edo karpeta bakarra markatu dezakezu gogoko gisa aldiko",
    "New folder" : "Karpeta berria",
    "Upload file" : "Kargatu fitxategia",
    "Recent" : "Azkenak",
    "Not favorited" : "Ez da gogokoa",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add to favorites" : "Gehitu gogokoetara",
    "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzen saiatzean",
    "Added to favorites" : "Gogokoetara gehitu da",
    "Removed from favorites" : "Gogokoetatik kendu da",
    "You added {file} to your favorites" : "{file} gehitu duzu gogokoetara",
    "You removed {file} from your favorites" : "{file} kendu duzu gogokoetatik",
    "File changes" : "Fitxategi aldaketak",
    "Created by {user}" : "{user} erabiltzaileak sortua",
    "Changed by {user}" : "{user} erabiltzaileak aldatua",
    "Deleted by {user}" : "{user} erabiltzaileak ezabatua",
    "Restored by {user}" : "{user} erabiltzaileak leheneratua",
    "Renamed by {user}" : "{user} erabiltzaileak berrizendatua",
    "Moved by {user}" : "{user} erabiltzaileak lekuz aldatua",
    "\"remote user\"" : "\"urruneko erabiltzailea\"",
    "You created {file}" : "{file} sortu duzu",
    "You created an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat sortu duzu",
    "{user} created {file}" : "{user} erabiltzaileak {file} sortu du",
    "{user} created an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat sortu du {file} karpetan",
    "{file} was created in a public folder" : "{file} sortu da karpeta publiko batean",
    "You changed {file}" : "{file} aldatu duzu",
    "You changed an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat aldatu duzu",
    "{user} changed {file}" : "{user} erabiltzaileak {file} aldatu du",
    "{user} changed an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat aldatu du {file} karpetan",
    "You deleted {file}" : "{file} ezabatu duzu",
    "You deleted an encrypted file in {file}" : "Enkriptatutako fitxategi bat ezabatu duzu {file} karpetan",
    "{user} deleted {file}" : "{user} erabiltzaileak {file} ezabatu du",
    "{user} deleted an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat ezabatu du {file} karpetan",
    "You restored {file}" : "{file} leheneratu duzu",
    "{user} restored {file}" : "{user} erabiltzaileak {file} leheneratu du",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (ezkutukoa) {newfile} (ezkutukoa) bezala berrizendatu duzu",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (ezkutukoa) {newfile} bezala berrizendatu duzu",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile} {newfile} (ezkutukoa) bezala berrizendatu duzu",
    "You renamed {oldfile} to {newfile}" : "{oldfile} {newfile} bezala berrizendatu duzu",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} erabiltzaileak {oldfile} (ezkutukoa) {newfile} (ezkutukoa) bezala berrizendatu du",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} erabiltzaileak {oldfile} (ezkutukoa) {newfile} bezala berrizendatu du",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} erabiltzaileak {oldfile} {newfile} (ezkutukoa) bezala berrizendatu du",
    "{user} renamed {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} {newfile} bezala berrizendatu du",
    "You moved {oldfile} to {newfile}" : "{oldfile} lekuz aldatu duzu {newfile}(e)ra",
    "{user} moved {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} lekuz aldatu du {newfile}(e)ra",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Gogoko fitxategi edo karpeta bat <strong>aldatu</strong> egin da.",
    "All files" : "Fitxategi guztiak",
    "Upload (max. %s)" : "Kargatu (%s gehienez)",
    "Accept" : "Onartu",
    "Reject" : "Ukatu",
    "Incoming ownership transfer from {user}" : "{user}(r)en jabetza-transferentzia",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} onartu nahi duzu?\n\nOharra: onarpenaren ondoren transferentzia prozesuak ordu 1 iraun dezake.",
    "Ownership transfer failed" : "Jabetzaren transferentziak huts egin du",
    "Your ownership transfer of {path} to {user} failed." : "{path}(r)en jabetza {user} erabiltzaileari transferitzeak huts egin du.",
    "The ownership transfer of {path} from {user} failed." : "{path}(r)ren jabetza {user} erabiltzailetik transferitzeak huts egin du.",
    "Ownership transfer done" : "Jabetzaren transferentzia egina",
    "Your ownership transfer of {path} to {user} has completed." : "{path}(r)en jabetza {user} erabiltzaileari transferitzea osatu da.",
    "The ownership transfer of {path} from {user} has completed." : "{path}(r)en jabetza {user} erabiltzailetik transferitzea osatu da.",
    "in %s" : "%s(e)n",
    "File Management" : "Fitxategi-kudeaketa",
    "Reload current directory" : "Birkargatu uneko direktorioa",
    "Go to the \"{dir}\" directory" : "Joan \"{dir}\" direktoriora",
    "Select the row for {displayName}" : "Hautatu {displayName} errenkada",
    "Open folder {name}" : "Ireki {name} karpeta",
    "Download file {name}" : "Deskargatu {name} fitxategia ",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
    "Total rows summary" : "Errenkaden guztirako laburpena",
    "Select all" : "Hautatu dena",
    "Unselect all" : "Desautatu dena",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\"-k huts egin du elementu batzuetan",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
    "ascending" : "goranzkoa",
    "descending" : "beheranzkoa",
    "Sort list by {column} ({direction})" : "Ordenatu zerrenda {zutabea} ({norabidea}) arabera",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
    "Storage informations" : "Biltegiaren informazioak",
    "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
    "{relative}% used" : "%{relative} erabilita",
    "Could not refresh storage stats" : "Ezin izan da biltegiratze maila freskatu",
    "Transfer ownership of a file or folder" : "Transferitu fitxategiaren edo karpetaren jabetza",
    "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
    "Change" : "Aldatu",
    "New owner" : "Jabe berria",
    "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
    "Transfer" : "Transferitu",
    "Transfer {path} to {userid}" : "Transfereritu {path}  {userid} erabiltzaileari",
    "Invalid path selected" : "Bide baliogabea hautatuta",
    "Unknown error" : "Errore ezezaguna",
    "Ownership transfer request sent" : "Jabetza transferentzia eskaera bidalita",
    "Cannot transfer ownership of a file or folder you do not own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
    "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
    "Loading current folder" : "Uneko karpeta kargatzen",
    "No files in here" : "Ez dago fitxategirik hemen",
    "No files or folders have been deleted yet" : "Oraindik ez da ezabatu fitxategirik edo karpetarik",
    "Go to the previous folder" : "Joan aurreko karpetara",
    "Go back" : "Atzera",
    "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
    "Files settings" : "FItxategien ezarpenak",
    "File cannot be accessed" : "Ezin da fitxategia atzitu",
    "You might not have have permissions to view it, ask the sender to share it" : "Baliteke hura ikusteko baimenik ez izatea; eskatu igorleari partekatzeko",
    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
    "Crop image previews" : "Moztu irudien aurrebistak",
    "Additional settings" : "Ezarpen gehiago",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopiatu arbelera",
    "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
    "Clipboard is not available" : "Arbela ez dago erabilgarri",
    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
    "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
    "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
    "Cancel" : "Utzi",
    "Create" : "Sortu",
    "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
    "Creating file" : "Fitxategia sortzen",
    "Blank" : "Hutsik",
    "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
    "Delete permanently" : "Ezabatu betirako",
    "Set up templates folder" : "Konfiguratu txantiloien karpeta",
    "Templates" : "Txantiloiak",
    "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
    "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda",
    "Toggle grid view" : "Txandakatu sareta ikuspegia",
    "Upload some content or sync with your devices!" : "Kargatu edukiren bat edo sinkronizatu zure gailuekin!",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Upload too large" : "Kargatzea handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kargatzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute.",
    "No favorites yet" : "Gogokorik ez oraindik",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
    "Shares" : "Partekatzeak",
    "Shared with others" : "Besteekin partekatuta",
    "Shared with you" : "Zurekin partekatuta",
    "Shared by link" : "Esteka bidez partekatuta",
    "Deleted shares" : "Ezabatutako partekatzeak",
    "Pending shares" : "Zain dauden partekatzeak",
    "Text file" : "Testu-fitxategia",
    "New text file.txt" : "Testu-fitxategi berria.txt",
    "Storage invalid" : "Biltegi baliogabea",
    "Select" : "Hautatu",
    "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
    "New" : "Berria",
    "Copied!" : "Kopiatua!",
    "Unlimited" : "Mugarik gabe",
    "Search users" : "Bilatu erabiltzaileak",
    "Cannot transfer ownership of a file or folder you don't own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
    "%s used" : "%s erabilita",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "%1$s / %2$s erabilita",
    "Settings" : "Ezarpenak",
    "Deleted files" : "Ezabatutako fitxategiak"
},
"nplurals=2; plural=(n != 1);");
